<?php

//Include the common file
require('../common.php');

//Check if the user is logged in
if (!$authentication->logged_in() || !$authentication->is_admin()) header("Location: login.php");

//User details
$user = $authentication->get_user($session->get('user_id'));
	
//Check if the form has been submitted
if (isset($_POST['submit'])) {

	$validate->required($_POST['first_name'], 'Enter your first name.');
	$validate->required($_POST['last_name'], 'Enter your last name.');
	$validate->email($_POST['email'], 'Email address not valid.');

	if (!empty($_POST['password'])) {
		
		$validate->required($_POST['password'], 'Insert password.');
		$validate->matches($_POST['password'], $_POST['confirm_password'], 'The password field does not match the confirm password field.');
	
	}
		
	if (!$error->has_errors()) {

		$additional_data = array(
			'first_name' 	=> $_POST['first_name'],
			'last_name' 	=> $_POST['last_name']
		);
		
		if (!empty($_POST['password']))
			$password = $_POST['password'];
		else
			$password = false;
					
		$authentication->update_user($session->get('user_id'), $user['user_email'], $password, $additional_data);
		
		$session->set('success', true);
		
		header('Location: users.php');
						
	}
	
}

?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
	
<!-- BEGIN head -->	
<head>
	
	<!-- Meta Tags -->
	<meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /> 
	
	<!-- Title -->
	<title>Authentication System</title>

	<!-- Style sheet -->
	<link href="css/style.css" rel="stylesheet" type="text/css" />
	<link href="css/reset.css" rel="stylesheet" type="text/css" />
	<link href="css/text.css" rel="stylesheet" type="text/css" />
	<link href="css/960.css" rel="stylesheet" type="text/css" />
	<link href="css/jquery.qtip.min.css" rel="stylesheet" type="text/css" />

	<!-- jQuery -->
	<script type="text/javascript" src="js/jquery.min.js"></script>
	<!-- jQuery plugins -->
	<script type="text/javascript" src="js/jquery.qtip.min.js"></script>
		
	<!-- Custom js -->
	<script type="text/javascript" src="js/custom.js"></script>
	
</head>
<!-- END head -->

<!-- BEGIN body -->
<body>

<!-- BEGIN #wrapper -->
<div id="wrapper">
	
	<!-- BEGIN #header -->
	<div id="header" class="container_12">
		
		<!-- BEGIN .grid_8 -->						
		<div class="grid_8">
			<a href="index.php"><img src="images/logo.png" alt="" /></a>
		</div>
		<!-- END .grid_8 -->
		
		<!-- BEGIN #user_menu -->
		<div id="user_menu" class="grid_4">
			<ul>
				<li><span><strong>Welcome:</strong> <?php if ($session->get('user_email')) echo $session->get('user_email'); ?></span></li>
				<li><a href="index.php"><img src="images/home.png" alt="" /></a></li>
				<li><a href="account.php"><img src="images/user.png" alt="" title="Profile" /></a></li>
				<li><a href="index.php?logout"><img src="images/logout.png" alt="" title="Logout" /></a></li>
			</ul>
		</div>
		<!-- END #user_menu -->
		
		<div class="clear">&nbsp;</div>
		
		<div class="grid_12 line">&nbsp;</div>
		
		<div class="clear">&nbsp;</div>
		
		<!-- BEGIN #main_menu -->
		<div id="main_menu" class="grid_9">
			<ul>
				<li><a href="users.php" <?php if (in_array(basename($_SERVER['PHP_SELF']), array('users.php', 'add_user.php', 'edit_user.php'))) echo 'class="current"'; ?>>Users</a></li>
				<li><a href="groups.php" <?php if (in_array(basename($_SERVER['PHP_SELF']), array('groups.php', 'add_group.php', 'edit_group.php'))) echo 'class="current"'; ?>>Groups</a></li>
				<li><a href="settings.php" <?php if (in_array(basename($_SERVER['PHP_SELF']), array('settings.php'))) echo 'class="current"'; ?>>Settings</a></li>
			</ul>
		</div>
		<!-- END #main_menu -->
				
		<div class="clear">&nbsp;</div>
						
	</div>
	<!-- END #header -->
	
	<?php if (is_dir(realpath(dirname(__FILE__) . '/../') . '/install')): ?>
		<div class="container_12">
			<div class="grid_12 alert error">
				<span>
					<strong>Warning</strong>
				</span>	
				<p>Install folder still exists and should be deleted for security reasons.</p>
			</div>
			<div class="clear"></div>
		</div>
	<?php endif; ?>

	<noscript>
		<div class="container_12">
			<div class="grid_12 alert error">
				<span>
					<strong>Warning</strong>
				</span>	
				<p>
					Many features on the web site require Javascript and cookies, you can enable both via your browser's
					preference settings.
				</p>
			</div>
			<div class="clear"></div>
		</div>
	</noscript>
	
	<!-- BEGIN #main -->
	<div id="main" class="container_12">
									
		<!-- BEGIN .grid_12 -->
		<div class="grid_12">

			<!-- BEGIN .title_background -->
			<div class="title_background">
				<h1>Your profile</h1>
			</div>
			<!-- END .title_background -->
		
			<?php if ($error->has_errors()): ?>
				
				<div class="alert error">
					<span>
						<strong>An error occurred while processing request</strong>
					</span>
					<?php foreach ($error->display_errors() as $value): ?>		
						<p><?php echo $value; ?></p>
					<?php endforeach; ?>
				</div>

			<?php $error->clear_errors(); endif; ?>
			
			<form action="" method="post">

				<p>
					<label><?php echo $user['first_name']; ?> <?php echo $user['last_name']; ?>:</label>
					<a href="http://gravatar.com/emails/" target="_blank">
						<img src="<?php echo get_gravatar($user['user_email'], 48, config_item('authentication', 'site_url') . 'admin/images/gravatar_48.png'); ?>" alt="" title="Change your avatar at gravatar.com" class="gravatar" />
					</a>
				</p>
														
				<p>
					<label>First name: <span title="Required field">*</span></label>
					<input type="text" name="first_name" size="50" value="<?php echo $user['first_name']; ?>" />
				</p>
									
				<p>
					<label>Last name: <span title="Required field">*</span></label>
					<input type="text" name="last_name" size="50" value="<?php echo $user['last_name']; ?>" />
				</p>
									
				<p>
					<label>Email address: <span title="Required field">*</span></label>
					<input type="text" name="email" size="50" value="<?php echo $user['user_email']; ?>" readonly="readonly" />
				</p>
										
				<p>
					<label>Password: </label>
					<input type="password" name="password" size="50" />
				</p>

				<p>
					<label>Confirm password: </label>
					<input type="password" id="confirm_password" name="confirm_password" size="50" />
				</p>
					
				<p>
					<button type="submit" name="submit" class="button orange">Save</button>
				</p>
									
			</form>
																		
		</div>
		<!-- END .grid_12 -->
		
		<div class="clear">&nbsp;</div>
		
	</div>
	<!-- END #main -->

</div>
<!-- END #wrapper -->

<!-- BEGIN .container_12 -->
<div class="container_12">
	
	<!-- BEGIN #footer -->
	<div id="footer" class="grid_12 text_center">
		<p>Copyright &copy; 2012 Gnt Studio</p>
	</div>
	<!-- END #footer -->
	
	<div class="clear">&nbsp;</div>
	
</div>
<!-- END .container_12 -->
			
</body>
<!-- END body -->

</html>
